/*
Licensed under GNU LGPL
*/

/********************************************************************************
** Form generated from reading UI file 'configui.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUI_H
#define UI_CONFIGUI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "sonnet/dictionarycombobox.h"

QT_BEGIN_NAMESPACE

class Ui_SonnetConfigUI
{
public:
    QGridLayout *gridLayout;
    Sonnet::DictionaryComboBox *m_langCombo;
    QGroupBox *groupBox1;
    QGridLayout *gridLayout1;
    QCheckBox *m_autodetectCB;
    QCheckBox *m_bgSpellCB;
    QCheckBox *m_checkerEnabledByDefaultCB;
    QCheckBox *m_skipUpperCB;
    QCheckBox *m_skipRunTogetherCB;
    QLabel *textLabel1;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QGridLayout *ignoredWordsLayout;
    QListWidget *ignoreListWidget;
    QLineEdit *newIgnoreEdit;
    QPushButton *addButton;
    QVBoxLayout *removeButtonLayout;
    QPushButton *removeButton;
    QSpacerItem *verticalSpacer;
    QLabel *nobackendfound;

    void setupUi(QWidget *SonnetConfigUI)
    {
        if (SonnetConfigUI->objectName().isEmpty())
            SonnetConfigUI->setObjectName(QStringLiteral("SonnetConfigUI"));
        SonnetConfigUI->resize(577, 441);
        gridLayout = new QGridLayout(SonnetConfigUI);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        gridLayout->setContentsMargins(0, 0, 0, 0);
        m_langCombo = new Sonnet::DictionaryComboBox(SonnetConfigUI);
        m_langCombo->setObjectName(QStringLiteral("m_langCombo"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_langCombo->sizePolicy().hasHeightForWidth());
        m_langCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(m_langCombo, 1, 1, 1, 1);

        groupBox1 = new QGroupBox(SonnetConfigUI);
        groupBox1->setObjectName(QStringLiteral("groupBox1"));
        gridLayout1 = new QGridLayout(groupBox1);
        gridLayout1->setObjectName(QStringLiteral("gridLayout1"));
        m_autodetectCB = new QCheckBox(groupBox1);
        m_autodetectCB->setObjectName(QStringLiteral("m_autodetectCB"));

        gridLayout1->addWidget(m_autodetectCB, 0, 0, 1, 1);

        m_bgSpellCB = new QCheckBox(groupBox1);
        m_bgSpellCB->setObjectName(QStringLiteral("m_bgSpellCB"));

        gridLayout1->addWidget(m_bgSpellCB, 1, 0, 1, 1);

        m_checkerEnabledByDefaultCB = new QCheckBox(groupBox1);
        m_checkerEnabledByDefaultCB->setObjectName(QStringLiteral("m_checkerEnabledByDefaultCB"));

        gridLayout1->addWidget(m_checkerEnabledByDefaultCB, 2, 0, 1, 1);

        m_skipUpperCB = new QCheckBox(groupBox1);
        m_skipUpperCB->setObjectName(QStringLiteral("m_skipUpperCB"));

        gridLayout1->addWidget(m_skipUpperCB, 3, 0, 1, 1);

        m_skipRunTogetherCB = new QCheckBox(groupBox1);
        m_skipRunTogetherCB->setObjectName(QStringLiteral("m_skipRunTogetherCB"));

        gridLayout1->addWidget(m_skipRunTogetherCB, 4, 0, 1, 1);


        gridLayout->addWidget(groupBox1, 2, 0, 1, 2);

        textLabel1 = new QLabel(SonnetConfigUI);
        textLabel1->setObjectName(QStringLiteral("textLabel1"));
        textLabel1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(textLabel1, 1, 0, 1, 1);

        groupBox = new QGroupBox(SonnetConfigUI);
        groupBox->setObjectName(QStringLiteral("groupBox"));
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        ignoredWordsLayout = new QGridLayout();
        ignoredWordsLayout->setObjectName(QStringLiteral("ignoredWordsLayout"));
        ignoreListWidget = new QListWidget(groupBox);
        ignoreListWidget->setObjectName(QStringLiteral("ignoreListWidget"));

        ignoredWordsLayout->addWidget(ignoreListWidget, 1, 0, 1, 1);

        newIgnoreEdit = new QLineEdit(groupBox);
        newIgnoreEdit->setObjectName(QStringLiteral("newIgnoreEdit"));

        ignoredWordsLayout->addWidget(newIgnoreEdit, 0, 0, 1, 1);

        addButton = new QPushButton(groupBox);
        addButton->setObjectName(QStringLiteral("addButton"));
        QIcon icon;
        QString iconThemeName = QStringLiteral("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        addButton->setIcon(icon);

        ignoredWordsLayout->addWidget(addButton, 0, 1, 1, 1);

        removeButtonLayout = new QVBoxLayout();
        removeButtonLayout->setObjectName(QStringLiteral("removeButtonLayout"));
        removeButton = new QPushButton(groupBox);
        removeButton->setObjectName(QStringLiteral("removeButton"));
        QIcon icon1;
        iconThemeName = QStringLiteral("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral("."), QSize(), QIcon::Normal, QIcon::Off);
        }
        removeButton->setIcon(icon1);

        removeButtonLayout->addWidget(removeButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        removeButtonLayout->addItem(verticalSpacer);


        ignoredWordsLayout->addLayout(removeButtonLayout, 1, 1, 1, 1);


        verticalLayout->addLayout(ignoredWordsLayout);


        gridLayout->addWidget(groupBox, 3, 0, 1, 2);

        nobackendfound = new QLabel(SonnetConfigUI);
        nobackendfound->setObjectName(QStringLiteral("nobackendfound"));
        QFont font;
        font.setBold(true);
        font.setItalic(true);
        font.setWeight(75);
        nobackendfound->setFont(font);
        nobackendfound->setAlignment(Qt::AlignCenter);

        gridLayout->addWidget(nobackendfound, 0, 0, 1, 2);


        retranslateUi(SonnetConfigUI);

        QMetaObject::connectSlotsByName(SonnetConfigUI);
    } // setupUi

    void retranslateUi(QWidget *SonnetConfigUI)
    {
        groupBox1->setTitle(QApplication::translate("SonnetConfigUI", "Options", Q_NULLPTR));
        m_autodetectCB->setText(QApplication::translate("SonnetConfigUI", "Enable autodetection of &language", Q_NULLPTR));
        m_bgSpellCB->setText(QApplication::translate("SonnetConfigUI", "Enable &background spellchecking", Q_NULLPTR));
        m_checkerEnabledByDefaultCB->setText(QApplication::translate("SonnetConfigUI", "&Automatic spell checking enabled by default", Q_NULLPTR));
        m_skipUpperCB->setText(QApplication::translate("SonnetConfigUI", "Skip all &uppercase words", Q_NULLPTR));
        m_skipRunTogetherCB->setText(QApplication::translate("SonnetConfigUI", "S&kip run-together words", Q_NULLPTR));
        textLabel1->setText(QApplication::translate("SonnetConfigUI", "Default language:", Q_NULLPTR));
        groupBox->setTitle(QApplication::translate("SonnetConfigUI", "Ignored Words:", Q_NULLPTR));
        addButton->setText(QApplication::translate("SonnetConfigUI", "&Add", Q_NULLPTR));
        removeButton->setText(QApplication::translate("SonnetConfigUI", "&Remove", Q_NULLPTR));
        nobackendfound->setText(QApplication::translate("SonnetConfigUI", "No backend found for spell checking", Q_NULLPTR));
        Q_UNUSED(SonnetConfigUI);
    } // retranslateUi

};

namespace Ui {
    class SonnetConfigUI: public Ui_SonnetConfigUI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CONFIGUI_H
