/****************************************************************************
** Meta object code from reading C++ file 'dialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/sonnet-5.39.0/src/ui/dialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Sonnet__Dialog_t {
    QByteArrayData data[35];
    char stringdata0[400];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Sonnet__Dialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Sonnet__Dialog_t qt_meta_stringdata_Sonnet__Dialog = {
    {
QT_MOC_LITERAL(0, 0, 14), // "Sonnet::Dialog"
QT_MOC_LITERAL(1, 15, 4), // "done"
QT_MOC_LITERAL(2, 20, 0), // ""
QT_MOC_LITERAL(3, 21, 9), // "newBuffer"
QT_MOC_LITERAL(4, 31, 11), // "misspelling"
QT_MOC_LITERAL(5, 43, 4), // "word"
QT_MOC_LITERAL(6, 48, 5), // "start"
QT_MOC_LITERAL(7, 54, 7), // "replace"
QT_MOC_LITERAL(8, 62, 7), // "oldWord"
QT_MOC_LITERAL(9, 70, 7), // "newWord"
QT_MOC_LITERAL(10, 78, 4), // "stop"
QT_MOC_LITERAL(11, 83, 6), // "cancel"
QT_MOC_LITERAL(12, 90, 11), // "autoCorrect"
QT_MOC_LITERAL(13, 102, 11), // "currentWord"
QT_MOC_LITERAL(14, 114, 11), // "replaceWord"
QT_MOC_LITERAL(15, 126, 16), // "spellCheckStatus"
QT_MOC_LITERAL(16, 143, 15), // "languageChanged"
QT_MOC_LITERAL(17, 159, 8), // "language"
QT_MOC_LITERAL(18, 168, 9), // "setBuffer"
QT_MOC_LITERAL(19, 178, 15), // "slotMisspelling"
QT_MOC_LITERAL(20, 194, 8), // "slotDone"
QT_MOC_LITERAL(21, 203, 12), // "slotFinished"
QT_MOC_LITERAL(22, 216, 10), // "slotCancel"
QT_MOC_LITERAL(23, 227, 11), // "slotAddWord"
QT_MOC_LITERAL(24, 239, 15), // "slotReplaceWord"
QT_MOC_LITERAL(25, 255, 14), // "slotReplaceAll"
QT_MOC_LITERAL(26, 270, 8), // "slotSkip"
QT_MOC_LITERAL(27, 279, 11), // "slotSkipAll"
QT_MOC_LITERAL(28, 291, 11), // "slotSuggest"
QT_MOC_LITERAL(29, 303, 18), // "slotChangeLanguage"
QT_MOC_LITERAL(30, 322, 20), // "slotSelectionChanged"
QT_MOC_LITERAL(31, 343, 15), // "slotAutocorrect"
QT_MOC_LITERAL(32, 359, 13), // "setGuiEnabled"
QT_MOC_LITERAL(33, 373, 1), // "b"
QT_MOC_LITERAL(34, 375, 24) // "setProgressDialogVisible"

    },
    "Sonnet::Dialog\0done\0\0newBuffer\0"
    "misspelling\0word\0start\0replace\0oldWord\0"
    "newWord\0stop\0cancel\0autoCorrect\0"
    "currentWord\0replaceWord\0spellCheckStatus\0"
    "languageChanged\0language\0setBuffer\0"
    "slotMisspelling\0slotDone\0slotFinished\0"
    "slotCancel\0slotAddWord\0slotReplaceWord\0"
    "slotReplaceAll\0slotSkip\0slotSkipAll\0"
    "slotSuggest\0slotChangeLanguage\0"
    "slotSelectionChanged\0slotAutocorrect\0"
    "setGuiEnabled\0b\0setProgressDialogVisible"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Sonnet__Dialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      24,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       8,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  134,    2, 0x06 /* Public */,
       4,    2,  137,    2, 0x06 /* Public */,
       7,    3,  142,    2, 0x06 /* Public */,
      10,    0,  149,    2, 0x06 /* Public */,
      11,    0,  150,    2, 0x06 /* Public */,
      12,    2,  151,    2, 0x06 /* Public */,
      15,    1,  156,    2, 0x06 /* Public */,
      16,    1,  159,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      18,    1,  162,    2, 0x0a /* Public */,
      19,    2,  165,    2, 0x08 /* Private */,
      20,    0,  170,    2, 0x08 /* Private */,
      21,    0,  171,    2, 0x08 /* Private */,
      22,    0,  172,    2, 0x08 /* Private */,
      23,    0,  173,    2, 0x08 /* Private */,
      24,    0,  174,    2, 0x08 /* Private */,
      25,    0,  175,    2, 0x08 /* Private */,
      26,    0,  176,    2, 0x08 /* Private */,
      27,    0,  177,    2, 0x08 /* Private */,
      28,    0,  178,    2, 0x08 /* Private */,
      29,    1,  179,    2, 0x08 /* Private */,
      30,    1,  182,    2, 0x08 /* Private */,
      31,    0,  185,    2, 0x08 /* Private */,
      32,    1,  186,    2, 0x08 /* Private */,
      34,    1,  189,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    5,    6,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,    8,    6,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   13,   14,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,   17,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    5,    6,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QModelIndex,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   33,
    QMetaType::Void, QMetaType::Bool,   33,

       0        // eod
};

void Sonnet::Dialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Dialog *_t = static_cast<Dialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->done((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->misspelling((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 2: _t->replace((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->stop(); break;
        case 4: _t->cancel(); break;
        case 5: _t->autoCorrect((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: _t->spellCheckStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->languageChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 8: _t->setBuffer((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->slotMisspelling((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->slotDone(); break;
        case 11: _t->slotFinished(); break;
        case 12: _t->slotCancel(); break;
        case 13: _t->slotAddWord(); break;
        case 14: _t->slotReplaceWord(); break;
        case 15: _t->slotReplaceAll(); break;
        case 16: _t->slotSkip(); break;
        case 17: _t->slotSkipAll(); break;
        case 18: _t->slotSuggest(); break;
        case 19: _t->slotChangeLanguage((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 20: _t->slotSelectionChanged((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        case 21: _t->slotAutocorrect(); break;
        case 22: _t->setGuiEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 23: _t->setProgressDialogVisible((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (Dialog::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::done)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)(const QString & , int );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::misspelling)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)(const QString & , int , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::replace)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::stop)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::cancel)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)(const QString & , const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::autoCorrect)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::spellCheckStatus)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (Dialog::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&Dialog::languageChanged)) {
                *result = 7;
                return;
            }
        }
    }
}

const QMetaObject Sonnet::Dialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_Sonnet__Dialog.data,
      qt_meta_data_Sonnet__Dialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Sonnet::Dialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sonnet::Dialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Sonnet__Dialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int Sonnet::Dialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void Sonnet::Dialog::done(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Sonnet::Dialog::misspelling(const QString & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Sonnet::Dialog::replace(const QString & _t1, int _t2, const QString & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Sonnet::Dialog::stop()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Sonnet::Dialog::cancel()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Sonnet::Dialog::autoCorrect(const QString & _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Sonnet::Dialog::spellCheckStatus(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Sonnet::Dialog::languageChanged(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
